==> v0.10.0.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/search/facets/statistical/StatisticalScriptFacetBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.search.facets.statistical;

import org.elasticsearch.common.collect.Maps;
import org.elasticsearch.common.xcontent.builder.XContentBuilder;
import org.elasticsearch.index.query.xcontent.XContentFilterBuilder;
import org.elasticsearch.search.builder.SearchSourceBuilderException;
import org.elasticsearch.search.facets.AbstractFacetBuilder;

import java.io.IOException;
import java.util.Map;

/**
 * @author kimchy (shay.banon)
 */
public class StatisticalScriptFacetBuilder extends AbstractFacetBuilder {
    private String script;
    private Map<String, Object> params;

    public StatisticalScriptFacetBuilder(String name) {
        super(name);
    }

    public StatisticalScriptFacetBuilder global(boolean global) {
        this.global = global;
        return this;
    }

    public StatisticalScriptFacetBuilder facetFilter(XContentFilterBuilder filter) {
        this.facetFilter = filter;
        return this;
    }

    public StatisticalScriptFacetBuilder script(String script) {
        this.script = script;
        return this;
    }

    public StatisticalScriptFacetBuilder param(String name, Object value) {
        if (params == null) {
            params = Maps.newHashMap();
        }
        params.put(name, value);
        return this;
    }

    @Override public void toXContent(XContentBuilder builder, Params params) throws IOException {
        if (script == null) {
            throw new SearchSourceBuilderException("script must be set on statistical script facet [" + name + "]");
        }
        builder.startObject(name);

        builder.startObject(StatisticalFacetCollectorParser.NAME);
        builder.field("script", script);
        if (this.params != null) {
            builder.field("params", this.params);
        }
        builder.endObject();

        addFilterFacetAndGlobal(builder, params);

        builder.endObject();
    }
}

==> v0.12.0.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/search/facets/statistical/StatisticalScriptFacetBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.search.facets.statistical;

import org.elasticsearch.common.collect.Maps;
import org.elasticsearch.common.xcontent.XContentBuilder;
import org.elasticsearch.index.query.xcontent.XContentFilterBuilder;
import org.elasticsearch.search.builder.SearchSourceBuilderException;
import org.elasticsearch.search.facets.AbstractFacetBuilder;

import java.io.IOException;
import java.util.Map;

/**
 * @author kimchy (shay.banon)
 */
public class StatisticalScriptFacetBuilder extends AbstractFacetBuilder {
    private String lang;
    private String script;
    private Map<String, Object> params;

    public StatisticalScriptFacetBuilder(String name) {
        super(name);
    }

    public StatisticalScriptFacetBuilder global(boolean global) {
        this.global = global;
        return this;
    }

    public StatisticalScriptFacetBuilder facetFilter(XContentFilterBuilder filter) {
        this.facetFilter = filter;
        return this;
    }

    /**
     * The language of the script.
     */
    public StatisticalScriptFacetBuilder lang(String lang) {
        this.lang = lang;
        return this;
    }

    public StatisticalScriptFacetBuilder script(String script) {
        this.script = script;
        return this;
    }

    public StatisticalScriptFacetBuilder param(String name, Object value) {
        if (params == null) {
            params = Maps.newHashMap();
        }
        params.put(name, value);
        return this;
    }

    @Override public void toXContent(XContentBuilder builder, Params params) throws IOException {
        if (script == null) {
            throw new SearchSourceBuilderException("script must be set on statistical script facet [" + name + "]");
        }
        builder.startObject(name);

        builder.startObject(StatisticalFacetCollectorParser.NAME);
        builder.field("script", script);
        if (lang != null) {
            builder.field("lang", lang);
        }
        if (this.params != null) {
            builder.field("params", this.params);
        }
        builder.endObject();

        addFilterFacetAndGlobal(builder, params);

        builder.endObject();
    }
}
